@@ -22,10 +22,10 @@
 #' @export
 common_network <- function(address1, address2) {
   if (!is_ip_address(address1)) {
-    abort("'address1' must be an ip_address vector")
+    abort("`address1` must be an ip_address vector")
   }
   if (!is_ip_address(address2)) {
-    abort("'address2' must be an ip_address vector")
+    abort("`address2` must be an ip_address vector")
   }
 
   # vector recycling
