@@ -39,6 +39,8 @@
 #' @param x
 #'  * For `ip_to_integer()`: An [`ip_address`] vector
 #'  * For `integer_to_ip()`: A character vector
+#' @param base A string choosing the numeric base of the output. Choices are
+#'   decimal (`"dec"`; the default), hexadecimal (`"hex"`), and binary (`"bin"`).
 #' @param is_ipv6 A logical vector indicating whether to construct an IPv4 or
 #'   IPv6 address. If `NULL` (the default), then integers less than 2^32 will
 #'   construct an IPv4 address and anything larger will construct an IPv6 address.
@@ -56,17 +58,25 @@
 #' # with IPv4 only, we can use numeric data type
 #' as.numeric(ip_to_integer(ip_address("192.168.0.1")))
 #'
-#' integer_to_ip(as.character(3232235521))
+#' integer_to_ip(3232235521)
+#'
+#' # hex representation
+#' ip_to_integer(x, base = "hex")
 #' @seealso
 #'  * [ip_to_bytes()] and [bytes_to_ip()]
 #'  * [ip_to_binary()] and [binary_to_ip()]
 #' @export
-ip_to_integer <- function(x) {
+ip_to_integer <- function(x, base = c("dec", "hex", "bin")) {
   if (!is_ip_address(x)) {
-    abort("'x' must be an ip_address vector")
+    abort("`x` must be an ip_address vector")
   }
 
-  wrap_encode_integer(x)
+  switch(
+    arg_match(base),
+    dec = wrap_encode_integer(x, FALSE),
+    hex = wrap_encode_integer(x, TRUE),
+    bin = wrap_encode_binary(x)
+  )
 }
 
 #' @rdname ip_to_integer
@@ -76,10 +86,10 @@ integer_to_ip <- function(x, is_ipv6 = NULL) {
     x <- as.character(x)
   }
   if (!is_character(x)) {
-    abort("'x' must be a character vector")
+    abort("`x` must be a character vector")
   }
   if (!(is_null(is_ipv6) || is_logical(is_ipv6))) {
-    abort("'is_ipv6' must be a logical vector or NULL")
+    abort("`is_ipv6` must be a logical vector or NULL")
   }
 
   # vector recycling
@@ -123,7 +133,7 @@ integer_to_ip <- function(x, is_ipv6 = NULL) {
 #' @export
 ip_to_bytes <- function(x) {
   if (!is_ip_address(x)) {
-    abort("'x' must be an ip_address vector")
+    abort("`x` must be an ip_address vector")
   }
 
   blob::new_blob(wrap_encode_bytes(x))
@@ -133,7 +143,7 @@ ip_to_bytes <- function(x) {
 #' @export
 bytes_to_ip <- function(x) {
   if (!blob::is_blob(x)) {
-    abort("'x' must be a blob object")
+    abort("`x` must be a blob object")
   }
 
   wrap_decode_bytes(x)
@@ -170,7 +180,7 @@ bytes_to_ip <- function(x) {
 #' @export
 ip_to_binary <- function(x) {
   if (!is_ip_address(x)) {
-    abort("'x' must be an ip_address vector")
+    abort("`x` must be an ip_address vector")
   }
 
   wrap_encode_binary(x)
@@ -180,8 +190,134 @@ ip_to_binary <- function(x) {
 #' @export
 binary_to_ip <- function(x) {
   if (!is_character(x)) {
-    abort("'x' must be a character vector")
+    abort("`x` must be a character vector")
   }
 
   wrap_decode_binary(x)
 }
+
+
+#' Translate address to/from hostname
+#'
+#' @description
+#' Perform reverse and forward DNS resolution.
+#'
+#' **Note:** These functions are significantly slower than others in the
+#' ipaddress package.
+#'
+#' @details
+#' These functions require an internet connection. Before processing the input
+#' vector, we first check that a known hostname can be resolved. If this fails,
+#' an error is raised.
+#'
+#' If DNS lookup cannot resolve an input, then `NA` is returned for that input.
+#' If an error occurs during DNS lookup, then a warning is emitted and `NA` is
+#' returned for that input.
+#'
+#' DNS resolution performs a many-to-many mapping between IP addresses and
+#' hostnames. For this reason, these two functions can potentially return
+#' multiple values for each element of the input vector. The `multiple` argument
+#' control whether _all_ values are returned (a vector for each input), or
+#' just the first value (a scalar for each input).
+#'
+#' @param x
+#'  * For `ip_to_hostname()`: An [`ip_address`] vector
+#'  * For `hostname_to_ip()`: A character vector of hostnames
+#' @param multiple A logical scalar indicating if _all_ resolved endpoints are
+#'   returned, or just the first endpoint (the default). This determines whether
+#'   a vector or list of vectors is returned.
+#'
+#' @return
+#' * For `ip_to_hostname()`: A character vector (`multiple = FALSE`) or
+#'   a list of character vectors (`multiple = TRUE`)
+#' * For `hostname_to_ip()`: A [`ip_address`] vector (`multiple = FALSE`) or
+#'   a list of [`ip_address`] vectors (`multiple = TRUE`)
+#'
+#' @examples
+#' \dontrun{
+#' hostname_to_ip("r-project.org")
+#'
+#' ip_to_hostname(hostname_to_ip("r-project.org"))
+#' }
+#' @seealso
+#' The base function `nsl()` provides forward DNS resolution to IPv4 addresses,
+#' but only on Unix-like systems.
+#' @export
+ip_to_hostname <- function(x, multiple = FALSE) {
+  if (!is_ip_address(x)) {
+    abort("`x` must be an ip_address vector")
+  }
+  if (!is_bool(multiple)) {
+    abort("`multiple` must be TRUE or FALSE")
+  }
+  if (is_offline()) {
+    abort("DNS resolution requires an internet connection")
+  }
+
+  out <- wrap_encode_hostname(x)
+
+  if (multiple) {
+    out
+  } else {
+    pluck_first_of_each(out)
+  }
+}
+
+#' @rdname ip_to_hostname
+#' @export
+hostname_to_ip <- function(x, multiple = FALSE) {
+  if (!is_character(x)) {
+    abort("`x` must be a character vector")
+  }
+  if (!is_bool(multiple)) {
+    abort("`multiple` must be TRUE or FALSE")
+  }
+  if (is_offline()) {
+    abort("DNS resolution requires an internet connection")
+  }
+
+  out <- wrap_decode_hostname(x)
+
+  if (multiple) {
+    out
+  } else {
+    pluck_first_of_each(out)
+  }
+}
+
+is_offline <- function() {
+  out <- suppressWarnings(wrap_decode_hostname("www.r-project.org"))
+  out <- pluck_first_of_each(out)
+  is.na(out)
+}
+
+pluck_first_of_each <- function(x) {
+  do.call(Map, c(c, x))[[1]]
+}
+
+
+#' Reverse DNS pointer
+#'
+#' Returns the PTR record used by reverse DNS.
+#'
+#' @details
+#' These documents describe reverse DNS lookup in more detail:
+#'
+#' * **IPv4:** [RFC-1035 Section 3.5](https://tools.ietf.org/html/rfc1035)
+#' * **IPv6:** [RFC-3596 Section 2.5](https://tools.ietf.org/html/rfc3596)
+#'
+#' @param x An [`ip_address`] vector
+#' @return A character vector
+#'
+#' @examples
+#' reverse_pointer(ip_address("127.0.0.1"))
+#'
+#' reverse_pointer(ip_address("2001:db8::1"))
+#' @export
+reverse_pointer <- function(x) {
+  if (!is_ip_address(x)) {
+    abort("`x` must be an ip_address vector")
+  }
+
+  wrap_reverse_pointer(x)
+}
